..
    This file is part of Invenio.
    Copyright (C) 2017-2019 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


Authors
=======

Invenio module that adds PID relations to the Invenio-PIDStore module.

- CERN <info@inveniosoftware.org>
